@@ -39,23 +39,32 @@ setClass("lMatrix", representation("VIRTUAL"), contains = "Matrix")
 setClass("zMatrix", # letter 'z' is as in the names of Lapack subroutines
          representation(x = "complex", "VIRTUAL"), contains = "Matrix")
 
+# Virtual class of dense matrices
+setClass("denseMatrix", representation("VIRTUAL"), contains = "Matrix")
+
 # Virtual class of dense, numeric matrices
 setClass("ddenseMatrix",
          representation(rcond = "numeric", factors = "list", "VIRTUAL"),
-         contains = "dMatrix")
+         contains = c("dMatrix", "denseMatrix"))
 
 # Virtual class of dense, logical matrices
 setClass("ldenseMatrix",
          representation(x = "logical", factors = "list", "VIRTUAL"),
-         contains = "lMatrix")
+         contains = c("lMatrix", "denseMatrix"))
 
 ## virtual SPARSE ------------
 
-setClass("sparseMatrix", contains = "Matrix")# "VIRTUAL"
+setClass("sparseMatrix", representation("VIRTUAL"), contains = "Matrix")
 
-setClass("dsparseMatrix", contains = c("dMatrix", "sparseMatrix"))# "VIRTUAL"
+## general Triplet Matrices (dgT, lgT, ..):
+setClass("gTMatrix", representation(i = "integer", j = "integer", "VIRTUAL"),
+         contains = "sparseMatrix")
 
-setClass("lsparseMatrix", contains = c("lMatrix", "sparseMatrix"))# "VIRTUAL"
+setClass("dsparseMatrix", representation("VIRTUAL"),
+         contains = c("dMatrix", "sparseMatrix"))
+
+setClass("lsparseMatrix", representation("VIRTUAL"),
+         contains = c("lMatrix", "sparseMatrix"))
 
 ## ------------------ Proper (non-virtual) Classes ----------------------------
 
@@ -113,11 +122,11 @@ setClass("dppMatrix", contains = "dspMatrix",
 ##-------------------- S P A R S E (non-virtual) --------------------------
 
 ##---------- numeric sparse matrix classes --------------------------------
-    
+
 # numeric, sparse, triplet general matrices
 setClass("dgTMatrix",
-         representation(i = "integer", j = "integer", factors = "list"),
-         contains = "dsparseMatrix",
+         representation(factors = "list"),
+         contains = c("gTMatrix", "dsparseMatrix"),
          validity = function(object) .Call("dgTMatrix_validate", object)
          )
 
@@ -160,32 +169,31 @@ setClass("dsCMatrix",
 setClass("dgRMatrix",
          representation(j = "integer", p = "integer", factors = "list"),
          contains = "dsparseMatrix",
-         validity = function(object) .Call("dgRMatrix_validate", object)
+         ##TODO: validity = function(object) .Call("dgRMatrix_validate", object)
          )
 
 # numeric, sparse, sorted compressed sparse row-oriented triangular matrices
 setClass("dtRMatrix",
          representation(uplo = "character", diag = "character"),
          contains = "dgRMatrix",
-         validity = function(object) .Call("dtRMatrix_validate", object)
+         ##TODO: validity = function(object) .Call("dtRMatrix_validate", object)
          )
 
 # numeric, sparse, sorted compressed sparse row-oriented symmetric matrices
 setClass("dsRMatrix",
          representation(uplo = "character"),
          contains = "dgRMatrix",
-         validity = function(object) .Call("dsRMatrix_validate", object)
+         ##TODO: validity = function(object) .Call("dsRMatrix_validate", object)
          )
 
 ##---------- logical sparse matrix classes --------------------------------
 
 ## these classes are used in symbolic analysis to determine the
-## locations of non-zero entries 
+## locations of non-zero entries
 
 # logical, sparse, triplet general matrices
 setClass("lgTMatrix",
-         representation(i = "integer", j = "integer"),
-         contains = "lsparseMatrix",
+         contains = c("gTMatrix", "lsparseMatrix"),
          validity = function(object) .Call("lgTMatrix_validate", object)
          )
 
@@ -359,7 +367,7 @@ setClass("lmer",
                         logLik = "logLik", residuals = "numeric",
                         terms = "terms"),
          contains = "mer")
-                                
+
 ## Representation of a generalized linear mixed effects model
 ##setClass("glmer",
 ##         representation(family = "family", glmmll = "numeric", fixed = "numeric"),
