@@ -104,3 +104,42 @@ SEXP dgTMatrix_to_matrix(SEXP x)
     UNPROTECT(1);
     return ans;
 }
+
+SEXP graphNEL_as_dgTMatrix(SEXP x)
+{
+    SEXP nodes = GET_SLOT(x, install("nodes")),
+	edgeL = GET_SLOT(x, install("edgeL")),
+	ans = PROTECT(NEW_OBJECT(MAKE_CLASS("dsTMatrix")));
+    int *ii, *jj, *dims, i, j, nnd = LENGTH(nodes), pos, totl;
+    double *xx;
+    
+    totl = 0;
+    for (i = 0; i < nnd; i++)
+	totl += LENGTH(Matrix_getElement(VECTOR_ELT(edgeL, i), "edges"));
+    dims = INTEGER(ALLOC_SLOT(ans, Matrix_DimSym, INTSXP, 2));
+    dims[0] = dims[1] = nnd;
+    if (isString(nodes)) {
+	SEXP dnms = ALLOC_SLOT(ans, Matrix_DimNamesSym, VECSXP, 2);
+	SET_VECTOR_ELT(dnms, 0, duplicate(nodes));
+	SET_VECTOR_ELT(dnms, 1, duplicate(nodes));
+    }
+    ii = INTEGER(ALLOC_SLOT(ans, Matrix_iSym, INTSXP, totl));
+    jj = INTEGER(ALLOC_SLOT(ans, Matrix_jSym, INTSXP, totl));
+    xx = REAL(ALLOC_SLOT(ans, Matrix_xSym, REALSXP, totl));
+    pos = 0;
+    for (i = 0; i < nnd; i++) {
+	SEXP edg = VECTOR_ELT(edgeL, i);
+	SEXP edges = Matrix_getElement(edg, "edges"),
+	    weights = Matrix_getElement(edg, "weights");
+	int *edgs = INTEGER(edges), nedg = LENGTH(edges);
+	double *wts = REAL(weights);
+	
+	for (j = 0; j < nedg; j++) {
+	    ii[pos] = i;
+	    jj[pos] = edgs[j] - 1;
+	    xx[pos] = wts[j];
+	}
+    }
+    UNPROTECT(1);
+    return ans;
+}
